@@ -592,10 +592,9 @@ impl Query {
         {
             let distribs = browserslist::resolve(
                 s,
-                &browserslist::Opts {
-                    mobile_to_desktop: true,
-                    ignore_unknown_versions: true,
-                },
+                browserslist::Opts::new()
+                    .mobile_to_desktop(true)
+                    .ignore_unknown_versions(true),
             )
             .with_context(|| {
                 format!(
